==> kadu_0.6.0.orig.tar.gz: kadu/modules/history/translations/history_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="53"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="6"/>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="9"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="12"/>
        <source>Save history</source>
        <translation>Salva Cronologia</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="14"/>
        <source>Save messages in history</source>
        <translation>Salva messaggi nella Cronologia</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Status changes</source>
        <translation>Cambiamenti dello status</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="21"/>
        <source>Don&apos;t show status changes</source>
        <translation>Non visualizza cambiamenti dello status</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="23"/>
        <source>Don&apos;t show status changes in history</source>
        <translation>Non visualizza cambiamenti dello status nella Cronologia</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="26"/>
        <source>Don&apos;t save status changes</source>
        <translation>Non memorizzi cambiamenti di status</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="28"/>
        <source>Don&apos;t save status changes in history</source>
        <translation>Non memorizzi cambiamenti di status nella Cronologia</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="32"/>
        <source>Citation</source>
        <translation>Citazione</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="35"/>
        <source>Message citation in chat window</source>
        <translation>Citazione messaggi nella finestra chat</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="38"/>
        <source>Don&apos;t cite messages older than</source>
        <translation>Non visualizza messagi più vecchi di</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="41"/>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="47"/>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="56"/>
        <source>View history</source>
        <translation>Mostra cronologia</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <location filename="../history_dialog.cpp" line="77"/>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="98"/>
        <source>&amp;Find</source>
        <translation>&amp;Trova</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="99"/>
        <source>Find &amp;next</source>
        <translation>Trova &amp;successivo</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="100"/>
        <source>Find &amp;previous</source>
        <translation>Trova &amp;precedente</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="216"/>
        <source>Online</source>
        <translation>Accessibile</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="220"/>
        <source>Busy</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="224"/>
        <source>Invisible</source>
        <translation>Invisibile</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="228"/>
        <source>Offline</source>
        <translation>Fuori linea</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="84"/>
        <source>Uins</source>
        <translation>Numero GG</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="91"/>
        <source>Show status changes</source>
        <translation>Visualizza cambiamenti dello status</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="231"/>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <location filename="../history.cpp" line="324"/>
        <source>Clear history?</source>
        <translation>Cancella Cronologia?</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <location filename="../history_module.cpp" line="75"/>
        <source>Show history</source>
        <translation>Mostra cronologia</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="335"/>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="336"/>
        <source>Clear history</source>
        <translation>Cancella Cronologia</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="140"/>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 giorno(i) %2 ora(e)</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="354"/>
        <source>The following users were deleted:
%0
Do you want to remove history as well?</source>
        <translation>Questi contatti erano rimossi:
%0
Davvero rimuovere anche la loro Chronologia?</translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <location filename="../history_search_dialog.cpp" line="39"/>
        <source>Search history</source>
        <translation>Cerca nella Cronologia</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="67"/>
        <source>&amp;From:</source>
        <translation>&amp;Da:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="90"/>
        <source>day</source>
        <translation>giorno</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="93"/>
        <source>month</source>
        <translation>mese</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="96"/>
        <source>year</source>
        <translation>anno</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="99"/>
        <source>hour</source>
        <translation>ora</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="102"/>
        <source>minute</source>
        <translation>minuto</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="86"/>
        <source>&amp;To:</source>
        <translation>&amp;A:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="104"/>
        <source>Find Criteria</source>
        <translation>Parametri Ricerca</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="105"/>
        <source>&amp;Pattern</source>
        <translation>&amp;Modello</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="106"/>
        <source>&amp;Status</source>
        <translation>&amp;Status</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="112"/>
        <source>Pattern</source>
        <translation>Modello</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="114"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="119"/>
        <source>&amp;Reverse find</source>
        <translation>&amp;Ricerca all&apos;indietro</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="121"/>
        <source>&amp;Find</source>
        <translation>&amp;Trova</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="122"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="123"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/history/translations/history_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Salva messaggi nella Cronologia</translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation>Cambiamenti dello status</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Visualizza cambiamenti dello status</translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation>Visualizza cambiamenti dello status nella Cronologia</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Memorizzi cambiamenti di status</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Memorizzi cambiamenti di status nella Cronologia</translation>
    </message>
    <message>
        <source>Citation</source>
        <translation>Citazione</translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation>Citazione messaggi nella finestra chat</translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation>Non visualizza messagi più vecchi di</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Mostra cronologia</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trova</translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation>Trova &amp;successivo</translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation>Trova &amp;precedente</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Accessibile</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisibile</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fuori linea</translation>
    </message>
    <message>
        <source>Uins</source>
        <translation>Numero GG</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Visualizza cambiamenti dello status</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation>Cancella Cronologia?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation>Mostra cronologia</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Cancella Cronologia</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 giorno(i) %2 ora(e)</translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation>Questi contatti erano rimossi:
%0Davvero rimuovere anche la loro Chronologia?</translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation>Cerca nella Cronologia</translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation>&amp;Da:</translation>
    </message>
    <message>
        <source>day</source>
        <translation>giorno</translation>
    </message>
    <message>
        <source>month</source>
        <translation>mese</translation>
    </message>
    <message>
        <source>year</source>
        <translation>anno</translation>
    </message>
    <message>
        <source>hour</source>
        <translation>ora</translation>
    </message>
    <message>
        <source>minute</source>
        <translation>minuto</translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation>Parametri Ricerca</translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation>&amp;Modello</translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation>&amp;Status</translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation>Modello</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation>&amp;Ricerca all&apos;indietro</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trova</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
</TS>
